==> json-joy-1.1.0.tgz: package/esm/json-pointer/util.js <==
export function unescapeComponent(component) {
    return component.replace(/~1/g, '/').replace(/~0/g, '~');
}
export function escapeComponent(component) {
    if (component.indexOf('/') === -1 && component.indexOf('~') === -1)
        return component;
    return component.replace(/~/g, '~0').replace(/\//g, '~1');
}
export function parseJsonPointer(pointer) {
    if (!pointer)
        return [];
    return pointer.slice(1).split('/').map(unescapeComponent);
}
export function formatJsonPointer(path) {
    if (isRoot(path))
        return '';
    return '/' + path.map(function (component) { return escapeComponent(String(component)); }).join('/');
}
export var toPath = function (pointer) { return (typeof pointer === 'string' ? parseJsonPointer(pointer) : pointer); };
export function isChild(parent, child) {
    if (parent.length >= child.length)
        return false;
    for (var i = 0; i < parent.length; i++)
        if (parent[i] !== child[i])
            return false;
    return true;
}
export function isPathEqual(p1, p2) {
    if (p1.length !== p2.length)
        return false;
    for (var i = 0; i < p1.length; i++)
        if (p1[i] !== p2[i])
            return false;
    return true;
}
export var isRoot = function (path) { return !path.length; };
export function parent(path) {
    if (path.length < 1)
        throw new Error('NO_PARENT');
    return path.slice(0, path.length - 1);
}
export function isValidIndex(index) {
    if (typeof index === 'number')
        return true;
    var n = parseInt(index, 10);
    return String(n) === index && n >= 0;
}
var Object$prototype$hasOwnProperty = Object.prototype.hasOwnProperty;
export function hasOwnProperty(obj, key) {
    return Object$prototype$hasOwnProperty.call(obj, key);
}

==> json-joy-1.3.0.tgz: package/esm/json-pointer/util.js <==
export function unescapeComponent(component) {
    return component.replace(/~1/g, '/').replace(/~0/g, '~');
}
export function escapeComponent(component) {
    if (component.indexOf('/') === -1 && component.indexOf('~') === -1)
        return component;
    return component.replace(/~/g, '~0').replace(/\//g, '~1');
}
export function parseJsonPointer(pointer) {
    if (!pointer)
        return [];
    return pointer.slice(1).split('/').map(unescapeComponent);
}
export function formatJsonPointer(path) {
    if (isRoot(path))
        return '';
    return '/' + path.map((component) => escapeComponent(String(component))).join('/');
}
export const toPath = (pointer) => (typeof pointer === 'string' ? parseJsonPointer(pointer) : pointer);
export function isChild(parent, child) {
    if (parent.length >= child.length)
        return false;
    for (let i = 0; i < parent.length; i++)
        if (parent[i] !== child[i])
            return false;
    return true;
}
export function isPathEqual(p1, p2) {
    if (p1.length !== p2.length)
        return false;
    for (let i = 0; i < p1.length; i++)
        if (p1[i] !== p2[i])
            return false;
    return true;
}
export const isRoot = (path) => !path.length;
export function parent(path) {
    if (path.length < 1)
        throw new Error('NO_PARENT');
    return path.slice(0, path.length - 1);
}
export function isValidIndex(index) {
    if (typeof index === 'number')
        return true;
    const n = parseInt(index, 10);
    return String(n) === index && n >= 0;
}
const Object$prototype$hasOwnProperty = Object.prototype.hasOwnProperty;
export function hasOwnProperty(obj, key) {
    return Object$prototype$hasOwnProperty.call(obj, key);
}
